## SCENARIO 3: Multiple entities; one inactive scenario; all valid

### INPUTS

#### GROUP 1: Unit Test

# | Title | Delimiter
--- | --- | ---
1 | Inner title 3 | ;;

####

#### GROUP 2: Input Fields

# | Group | Field
--- | --- | ---
1 | Input Group 1 | Input Field 1-1
2 | Input Group 1 | Input Field 1-2
3 | Input Group 2 | Input Field 2-1
4 | Input Group 2 | Input Field 2-2

####

#### GROUP 3: Output Fields

# | Group | Field
--- | --- | ---
1 | Output Group 1 | Output Field 1-1
2 | Output Group 1 | Output Field 1-2
3 | Output Group 2 | Output Field 2-1
4 | Output Group 2 | Output Field 2-2

####

#### GROUP 4: Scenario

# | Scenario | Active Y/N
--- | --- | ---
1 | Inner scenario 1 | Y
2 | Inner scenario 2 | N
3 | Inner scenario 3 | Y

####

#### GROUP 5: Input Values

# | Scenario | Group | Row CSV
--- | --- | --- | ---
1 | Inner scenario 1 | Input Group 1 | S1R1 IV-11;;R1 IV-12
2 | Inner scenario 1 | Input Group 1 | S1R2 IV-11;;R2 IV-12
3 | Inner scenario 1 | Input Group 2 | S1R1 IV-21;;R1 IV-22
4 | Inner scenario 1 | Input Group 2 | S1R2 IV-21;;R2 IV-22
5 | Inner scenario 2 | Input Group 2 | S2R2 IV-21;;R2 IV-22
6 | Inner scenario 3 | Input Group 1 | S3R1 IV-11;;R1 IV-12
7 | Inner scenario 3 | Input Group 1 | S3R2 IV-11;;R2 IV-12
8 | Inner scenario 3 | Input Group 2 | S3R1 IV-21;;R1 IV-22
9 | Inner scenario 3 | Input Group 2 | S3R2 IV-21;;R2 IV-22

####

#### GROUP 6: Expected Values

# | Scenario | Group | Row CSV
--- | --- | --- | ---
1 | Inner scenario 1 | Output Group 1 | S1R1 EV-11;;R1 EV-12
2 | Inner scenario 1 | Output Group 1 | S1R2 EV-11;;R2 EV-12
3 | Inner scenario 1 | Output Group 2 | S1R1 EV-21;;R1 EV-22
4 | Inner scenario 1 | Output Group 2 | S1R2 EV-21;;R2 EV-22
5 | Inner scenario 3 | Output Group 1 | S3R1 EV-11;;R1 EV-12
6 | Inner scenario 3 | Output Group 1 | S3R2 EV-11;;R2 EV-12
7 | Inner scenario 3 | Output Group 2 | S3R1 EV-21;;R1 EV-22
8 | Inner scenario 3 | Output Group 2 | S3R2 EV-21;;R2 EV-22

####

#### GROUP 7: Actual Values

# | Scenario | Group | Row CSV
--- | --- | --- | ---
1 | Inner scenario 1 | Output Group 1 | S1R1 EV-11;;R1 EV-12
2 | Inner scenario 1 | Output Group 1 | S1R2 EV-11;;R2 EV-12
3 | Inner scenario 1 | Output Group 2 | S1R1 EV-21;;R1 EV-22
4 | Inner scenario 1 | Output Group 2 | S1R2 EV-21;;R2 EV-22
5 | Inner scenario 3 | Output Group 1 | S3R1 EV-11;;R1 EV-12
6 | Inner scenario 3 | Output Group 1 | S3R2 EV-11;;R2 EV-12
7 | Inner scenario 3 | Output Group 2 | S3R1 EV-21;;R1 EV-22
8 | Inner scenario 3 | Output Group 2 | S3R2 EV-21;;R2 EV-22

####

### OUTPUTS

#### GROUP 1: Unit Test

# | Title | Delimiter
--- | --- | ---
1 | Inner title 3 | ;;

#### 0 failed of 1: SUCCESS

#### GROUP 2: Input Fields

# | Group | Field
--- | --- | ---
1 | Input Group 1 | Input Field 1-1
2 | Input Group 1 | Input Field 1-2
3 | Input Group 2 | Input Field 2-1
4 | Input Group 2 | Input Field 2-2

#### 0 failed of 4: SUCCESS

#### GROUP 3: Output Fields

# | Group | Field
--- | --- | ---
1 | Output Group 1 | Output Field 1-1
2 | Output Group 1 | Output Field 1-2
3 | Output Group 2 | Output Field 2-1
4 | Output Group 2 | Output Field 2-2

#### 0 failed of 4: SUCCESS

#### GROUP 4: Input Values

# | Scenario | Group | Row CSV
--- | --- | --- | ---
1 | Inner scenario 1 | Input Group 1 | S1R1 IV-11;;R1 IV-12
2 | Inner scenario 1 | Input Group 1 | S1R2 IV-11;;R2 IV-12
3 | Inner scenario 1 | Input Group 2 | S1R1 IV-21;;R1 IV-22
4 | Inner scenario 1 | Input Group 2 | S1R2 IV-21;;R2 IV-22
5 | Inner scenario 3 | Input Group 1 | S3R1 IV-11;;R1 IV-12
6 | Inner scenario 3 | Input Group 1 | S3R2 IV-11;;R2 IV-12
7 | Inner scenario 3 | Input Group 2 | S3R1 IV-21;;R1 IV-22
8 | Inner scenario 3 | Input Group 2 | S3R2 IV-21;;R2 IV-22

#### 0 failed of 8: SUCCESS

#### GROUP 5: Expected Values

# | Scenario | Group | Row CSV
--- | --- | --- | ---
1 | Inner scenario 1 | Output Group 1 | S1R1 EV-11;;R1 EV-12
2 | Inner scenario 1 | Output Group 1 | S1R2 EV-11;;R2 EV-12
3 | Inner scenario 1 | Output Group 2 | S1R1 EV-21;;R1 EV-22
4 | Inner scenario 1 | Output Group 2 | S1R2 EV-21;;R2 EV-22
5 | Inner scenario 3 | Output Group 1 | S3R1 EV-11;;R1 EV-12
6 | Inner scenario 3 | Output Group 1 | S3R2 EV-11;;R2 EV-12
7 | Inner scenario 3 | Output Group 2 | S3R1 EV-21;;R1 EV-22
8 | Inner scenario 3 | Output Group 2 | S3R2 EV-21;;R2 EV-22

#### 0 failed of 8: SUCCESS

#### GROUP 6: Actual Values

# | Scenario | Group | Row CSV
--- | --- | --- | ---
1 | Inner scenario 1 | Output Group 1 | S1R1 EV-11;;R1 EV-12
2 | Inner scenario 1 | Output Group 1 | S1R2 EV-11;;R2 EV-12
3 | Inner scenario 1 | Output Group 2 | S1R1 EV-21;;R1 EV-22
4 | Inner scenario 1 | Output Group 2 | S1R2 EV-21;;R2 EV-22
5 | Inner scenario 3 | Output Group 1 | S3R1 EV-11;;R1 EV-12
6 | Inner scenario 3 | Output Group 1 | S3R2 EV-11;;R2 EV-12
7 | Inner scenario 3 | Output Group 2 | S3R1 EV-21;;R1 EV-22
8 | Inner scenario 3 | Output Group 2 | S3R2 EV-21;;R2 EV-22

#### 0 failed of 8: SUCCESS

## 0 failed of 6: SUCCESS